/*
 * Svjatoslav Commons - shared library of common functionality.
 * Copyright ©2012-2019, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 */

package eu.svjatoslav.commons.network.navigation;

import eu.svjatoslav.commons.string.GlobMatcher;

import java.util.ArrayList;
import java.util.List;

public class NavigationItem {

    private final ArrayList<NavigationItem> children = new ArrayList<>();
    private final String url;
    private String pattern;
    private String title;
    private boolean isDefault;

    public NavigationItem(final String url, String pattern, String title ) {
        this.url = url;
        this.pattern = pattern;
        this.title = title;
    }

    public NavigationItem setDefault(){
        isDefault = true;
        return this;
    }

    public boolean isDefault(){
        return isDefault;
    }

    public void add(final NavigationItem navigationItem) {
        children.add(navigationItem);
    }

    public String getUrl() {
        return url;
    }

    NavigationItem getMatch(final String requestPath) {
        if (matchesUrl(requestPath))
            return this;

        for (final NavigationItem childNavigationItem : children) {
            final NavigationItem match = childNavigationItem.getMatch(requestPath);

            if (match != null)
                return match;
        }
        return null;
    }

    public List<NavigationItem> getChildren() {
        return children;
    }

    public String getTitle() {
        return title;
    }

    public boolean matchesUrl(final String url) {
        return GlobMatcher.match(url, pattern);
    }

    public NavigationItem getDefaultNavigationItem() {
        for (NavigationItem child : children)
            if (child.isDefault())
                return child;
        return null;
    }
}
